@@ -579,6 +579,14 @@ class Ingress(ExpiredEntity):
         self._life_time=_life_time
         super().__init__(_life_time)
 
+    @property
+    def hosts(self):
+        return [IngressHost(h) for h in self.host_info.get_value().split(',')]
+    
+    @property
+    def addresses(self):
+        return [Value(a) for a in self.address_info.get_value().split(',')]
+
 class DNSRecord(Entity):
     def __init__(
         self,
